@@ -16,7 +16,7 @@ from .oidc import set_oauth_cb
 
 def get_config(mode, config, **kwargs):
     # Merge configuration from user.
-    config = {**(config or {}), **kwargs}
+    config = update_config(config, kwargs)
 
     # SSL configuration.
     if config.setdefault("security.protocol", "sasl_ssl") == "sasl_ssl":
@@ -54,6 +54,12 @@ def get_config(mode, config, **kwargs):
     return config
 
 
+def update_config(config, **kwargs):
+    result = dict(config)
+    result.update({k: v for k, v in kwargs.items() if v is not None})
+    return result
+
+
 class Producer(confluent_kafka.Producer):
     def __init__(
         self,
@@ -79,8 +85,8 @@ class Producer(confluent_kafka.Producer):
                 **kwargs,
             )
         )
-        # Workaround for https://github.com/edenhill/librdkafka/issues/3263.
-        # FIXME: Remove once confluent-kafka-python 1.9.0 has been released.
+        # Workaround for https://github.com/edenhill/librdkafka/issues/3871.
+        # FIXME: Remove once fixed upstream, or on removal of oauth_cb.
         self.poll(0)
 
 
